C
C      ********************************************************
C      *                                                      *
C      *                    **** WTAQ ****                    *
C      *                                                      *
C      *      COMPUTER PROGRAM FOR CALCULATING DRAWDOWN       *
C      *                                                      *
C      *      IN A CONFINED OR WATER-TABLE AQUIFER WITH       *
C      *                                                      *
C      *        AXIAL-SYMMETRIC FLOW TO A FINITE- OR          *
C      *                                                      *
C      *         INFINITESIMAL-DIAMETER PUMPED WELL           *
C      *                                                      *
C      *        VERSION 1.3 CURRENT AS OF 06/29/2012          *
C      *                                                      *
C      ********************************************************
C
C
C      Although this program has been used by the U.S. Geological
C      Survey, no warranty, expressed or implied, is made by the 
C      USGS as to the accuracy and functioning of the program and
C      related program material, nor shall the fact of distribution
C      constitute any such warranty, and no responsibility is
C      assumed by the USGS in connection therewith
C
C---SPECIFICATIONS
C
C---THE PARAMETER STATEMENT BELOW SPECIFIES THE FOLLOWING PROGRAM
C   DIMENSIONS:
C    IMAXX1 = MAXIMUM NUMBER OF TIME-DRAWDOWN CURVES TO BE GENERATED
C             (THE FIRST CURVE IS ALWAYS THE PUMPED WELL, EVEN WHEN
C             CURVES ARE NOT CALCULATED AT THE PUMPED WELL).
C             IF IMAXX1 IS INCREASED, ADDITIONAL TEXT MUST BE ADDED
C             TO THE CHARACTER ARRAY 'WELLTXT'
C    IMAXX2 = MAXIMUM NUMBER OF USER SPECIFIED TIMES OR MEASURED 
C             DRAWDOWNS AT THE PUMPED WELL OR OBSERVATION WELLS
C
      PARAMETER (IMAXX1=25,IMAXX2=200)
C
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DIMENSION GAMMA(5)
      DIMENSION TDPLOT(IMAXX1,IMAXX2),HDPLOT(IMAXX1,IMAXX2)
      DIMENSION TIMEPW(IMAXX2),XMEASPW(IMAXX2),TIMEOB(IMAXX2),
     2 XMEASOB(IMAXX2)
      DIMENSION TDRDSQT(IMAXX2),TDRDSQTY(IMAXX2),HDTPLOT(IMAXX2),
     2 HDTYPLOT(IMAXX2)
      CHARACTER STRING*80,WELLTXT(IMAXX1)*6
      DATA WELLTXT/'HDPW','HDOB1','HDOB2','HDOB3','HDOB4',
     2 'HDOB5','HDOB6','HDOB7','HDOB8','HDOB9','HDOB10','HDOB11',
     3 'HDOB12','HDOB13','HDOB14','HDOB15','HDOB16','HDOB17',
     4 'HDOB18','HDOB19','HDOB20','HDOB21','HDOB22','HDOB23',
     5 'HDOB24'/
C
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ IPWD,IRUN,IPWS,NOBWC,IOWS,IDPR
      COMMON /PAR2/ NGAMMA,IDRA,NS,KK,NMAX,NTMS
      COMMON /PAR3/ IFORMAT,IAQ,NLC,NOX
      COMMON /PAR4/ ITS,IMEAS,NTSPW
      COMMON /PAR5/ BB,HKR,XKD,SS,SY,RW,QQ
      COMMON /PAR6/ BETAW,SIGMA,GAMMA
      COMMON /PAR7/ RERRNR,RERRSUM,TDLAST,TLAST
      COMMON /PAR8/ R,ZP,Z1,Z2,WDP
      COMMON /PAR9/ V(20),XLN2,EXPMAX
      COMMON /PAR10/ RD,ZD,ZD1,ZD2
      COMMON /PAR11/ XLD,XDD,WD,SW
      COMMON /PAR12/ TIMEPW, XMEASPW
C
C1--OPEN INPUT, RESULT, AND PLOT FILES
      CALL OFILE(IPLOT)
C
C2--READ AND PREPARE INPUT DATA
      CALL DATAPREP
C
C3--DEFINE SELECTED PROGRAM PARAMETERS
      PI=3.141592653589793D0
      IF(IFORMAT.GE.1)THEN
       F1=(SS*RW*RW)/HKR
       F2=QQ/(4.0D0*PI*HKR*BB)
      ENDIF
C
C---EXPMAX IS THE MAXIMUM ALLOWABLE ABSOLUTE VALUE OF EXPONENTIAL ARGUMENTS
       EXPMAX=708.D0
C
C4--CALL LINVST TO CALCULATE COEFFICIENTS USED FOR THE STEHFEST
C     ALGORITHM
       CALL LINVST(V,NS)
       XLN2=DLOG(2.D0)
C
C5--CALCULATE TIME-STEP PARAMETERS FOR LOG-CYCLE FORMATS
      IF(ITS.EQ.0)THEN
       NTS=NOX*NLC + 1
       DELTD=10.D0**(1.0D0/NOX)
      ENDIF
C
C6--CALCULATE REQUIRED NUMBER OF TIME-DRAWDOWN CURVES. ALWAYS
C    INCLUDE ONE CURVE FOR THE PUMPED WELL, EVEN IF RESULTS ARE
C    NOT PRINTED
      KKTOT=NOBWC+1
C
C7--CALCULATE TIME-DRAWDOWN CURVES FOR EACH WELL:
      DO 10 KK=1,KKTOT
C
C7a-CACULATE DIMENSIONLESS VARIABLES TO PASS TO LAPLACE TRANSFORM
C    SOLUTION SUBROUTINES 
C
C---IF KK=1, PUMPED-WELL CURVE
      IF(KK.EQ.1)THEN
       IF(IRUN.EQ.0)GO TO 10
       IOWS=2
       RD=1.0D0
       RDSQ=RD*RD
       ZD=0.0D0
       WDP=0.0D0
C--WRITE HEADERS TO RESULT AND PLOT FILES FOR PUMPED-WELL RESULTS
       IF(IFORMAT.EQ.0)WRITE(IO,100)
       IF(IFORMAT.GE.1)THEN
        IF(IMEAS.EQ.0)WRITE(IO,101)
        IF(IMEAS.EQ.1)WRITE(IO,102)
       ENDIF
C
       IF(IPLOT.EQ.1)THEN
        IF(IFORMAT.GE.1)THEN
         IF(ITS.GT.0)THEN
          IF(IMEAS.EQ.0)THEN
           WRITE(IP,103)
           WRITE(IP,104)
          ENDIF
          IF(IMEAS.EQ.1)THEN
           WRITE(IP,103)
           WRITE(IP,105)
          ENDIF
         ENDIF
        ENDIF
       ENDIF
C
C---ELSE, OBSERVATION-WELL CURVE--READ INPUT DATA
      ELSE
       KI=KK-1
       IF(KI.EQ.1)WRITE(IO,106)
       WRITE(IO,112)KI
C
       READ(IN,'(A80)') STRING
       ILINE=16
       READ(STRING,*,ERR=1000) IOWS, IDPR
C
       IF(IOWS.LT.0.OR.IOWS.GT.2)THEN
        WRITE(IO,107)
        STOP
       ENDIF
       IF(IDPR.LT.0.OR.IDPR.GT.1)THEN
        WRITE(IO,107)
        STOP
       ENDIF
       IF(IDPR.EQ.1)THEN
        IF(IOWS.EQ.2)THEN
         WRITE(IO,107)
         STOP
        ENDIF
       ENDIF
C
       READ(IN,'(A80)') STRING
       ILINE=17
       IF(IFORMAT.EQ.0)READ(STRING,*,ERR=1000) R, Z1, Z2, ZP, WDP
       IF(IFORMAT.GE.1)READ(STRING,*,ERR=1000) R, Z1, Z2, ZP, RP,
     2    XLL
C
       IF(R.LT.0.0D0.OR.ZP.LT.0.0D0)THEN
        WRITE(IO,108)
        STOP
       ENDIF
       IF(Z1.LT.0.0D0.OR.Z2.LT.0.0D0)THEN
        WRITE(IO,108)
        STOP
       ENDIF
C---Version 1.1: add tests for partially-penetrating wells:
      IF(IOWS.EQ.0)THEN
       IF(Z1.GE.Z2)THEN
        WRITE(IO,130)
        STOP
       ENDIF
       IF(Z1.GT.BB.OR.Z2.GT.BB)THEN
        WRITE(IO,131)
        STOP
       ENDIF
      ENDIF
C---Version 1.1: add test for observation piezometer:
      IF(IOWS.EQ.2)THEN
       IF(ZP.GT.BB)THEN
        WRITE(IO,132)
        STOP
       ENDIF
      ENDIF
C
       IF(WDP.LT.0.0D0.OR.RP.LT.0.0D0)THEN
        WRITE(IO,108)
        STOP
       ENDIF
       IF(XLL.LT.0.0D0)THEN
        WRITE(IO,108)
        STOP
       ENDIF
C
       RD=R/RW
       RDSQ=RD*RD
       BETA=BETAW*RDSQ
C
C---CALCULATE DIMENSIONLESS POSITION OF OBSERVATION WELL OR OBSERVATION
C    PIEZOMETER. NOTE SWITCH IN DEFINITION OF WELL-SCREEN POSITION FROM
C    WATER-TABLE REFERENCE TO BOTTOM-OF-AQUIFER REFERENCE
C
C---IF IOWS = 0, PARTIALLY PENETRATING OBSERVATION WELL
       IF(IOWS.EQ.0)THEN
        ZD=0.0D0
        ZD1=1.0D0 - (Z2/BB)
        ZD2=1.0D0 - (Z1/BB)
       ENDIF
C---IF IOWS = 1, FULLY PENETRATING OBSERVATION WELL
       IF(IOWS.EQ.1)THEN
C---Version 1.1: add additional test:
        IF(Z2.NE.BB)THEN
         WRITE(IO,133)
         STOP
        ENDIF
C
        BCALC=Z2-Z1
         IF(BCALC.NE.BB)THEN
          WRITE(IO,109)
          STOP
         ENDIF
        ZD=0.0D0
        ZD1=0.0D0
        ZD2=1.0D0
       ENDIF
C---IF IOWS = 2, OBSERVATION PIEZOMETER
       IF(IOWS.EQ.2)THEN
        ZD=1.0D0 - (ZP/BB)
        ZD1=0.0D0
        ZD2=0.0D0
       ENDIF
C
       IF(IDPR.EQ.0)WDP=0.0D0
       IF(IDPR.EQ.1)THEN
        IF(IFORMAT.GE.1)THEN
         XM=DSQRT(XKD)
         XX=XLL/(2.0D0*XM*RP)
         XXX=XX+DSQRT(1.0D0+XX*XX)
         FPRIME=XLL/DLOG(XXX)
         WDP=((RP/RW)**2)/(2.0D0*SS*FPRIME)
        ENDIF
       ENDIF
C
C---READ TIME-DRAWDOWN DATA
       IRUN=1
       IF(IFORMAT.GE.1)THEN
        IF(ITS.EQ.1)THEN
         READ(IN,'(A80)') STRING
         ILINE=18
         READ(STRING,*,ERR=1000) NTSOB, IRUN
         IF(NTSOB.LT.0)THEN
          WRITE(IO,110)
          STOP
         ENDIF
         IF(IRUN.LT.0.OR.IRUN.GT.1)THEN
          WRITE(IO,110)
          STOP
         ENDIF
         IF(NTSOB.EQ.0)THEN
          WRITE(IO,111)
          GOTO 10
         ENDIF
         IF(IMEAS.EQ.0)THEN
          DO 15 ID=1,NTSOB
           READ(IN,'(A80)') STRING
           ILINE=19
           READ(STRING,*,ERR=1000) TIMEOB(ID)
  15      CONTINUE
         ENDIF
         IF(IMEAS.EQ.1)THEN
          DO 20 ID=1,NTSOB
           READ(IN,'(A80)') STRING
           ILINE=19
           READ(STRING,*,ERR=1000) TIMEOB(ID),XMEASOB(ID)
  20      CONTINUE
         ENDIF
         DO 25 ID=1,NTSOB
          IF(TIMEOB(ID).LT.0.0D0)THEN
           WRITE(IO,110)
           STOP
          ENDIF
  25     CONTINUE
        ENDIF
       ENDIF
C
       IF(IRUN.EQ.0)THEN
        WRITE(IO,111)
        GOTO 10
       ENDIF
C
C---WRITE OBSERVATION-WELL INFORMATION TO RESULT AND PLOT FILES
       IF(IOWS.EQ.0)WRITE(IO,113)
       IF(IOWS.EQ.1)WRITE(IO,114)
       IF(IOWS.EQ.2)WRITE(IO,115)
       IF(IOWS.EQ.0.OR.IOWS.EQ.1)WRITE(IO,116)R,Z1,Z2,WDP
       IF(IOWS.EQ.2)WRITE(IO,117)R,ZP,WDP
       WRITE(IO,118)BETA
       IF(IFORMAT.EQ.0)WRITE(IO,100)
       IF(IFORMAT.GE.1)THEN
        IF(IMEAS.EQ.0)WRITE(IO,101)
        IF(IMEAS.EQ.1)WRITE(IO,102)
       ENDIF
C
       IF(IPLOT.EQ.1)THEN
        IF(IFORMAT.GE.1)THEN
         IF(ITS.GT.0)THEN
          IF(IMEAS.EQ.0)THEN
           WRITE(IP,112)KI
           WRITE(IP,104)
          ENDIF
          IF(IMEAS.EQ.1)THEN
           WRITE(IP,112)KI
           WRITE(IP,105)
          ENDIF
         ENDIF
        ENDIF
       ENDIF
C
C
C7a-FINISHED CALCULATING DIMENSIONLESS VARIABLES
      ENDIF
C
C7b-DEFINE DIMENSIONLESS TIME (TD) AND ITERATION VARIABLES
       IF(IFORMAT.EQ.0)TD=DELTD*TDLAST*RDSQ
       IF(IFORMAT.GE.1)RDSQ=1.0D0
       IF(IFORMAT.EQ.1)THEN
        IF(ITS.EQ.0)TD=TLAST*DELTD/F1
       ENDIF
C
C---IF USER-SPECIFIED TIMES ARE GIVEN, NTS IS THE NUMBER
C    OF SPECIFIED TIME STEPS
       IF(ITS.EQ.1)THEN
        IF(KK.EQ.1)NTS=NTSPW
        IF(KK.GT.1)NTS=NTSOB
       ENDIF
C
C7c-NOW, ENTER TIME-STEP LOOP
C
C---SET INITIAL VALUES OF SWITCHES FOR MINIMUM DRAWDOWN 
C   CALCULATIONS
       IHD=1
       IHDH=1
C
       DO 30 NT=1,NTS
        HD=0.0D0
C
C---DETERMINE DIMENSIONLESS TIME OF CURRENT TIME STEP.
C   DRAWDOWNS ARE CALCULATED FROM LARGEST TO SMALLEST TIME.
C   THUS, DIVIDE CURRENT TIME BY DELTD TO REDUCE TIME BY DELTD:
       IF(IFORMAT.EQ.0)TD=TD/DELTD
       IF(IFORMAT.GE.1)THEN
        IF(ITS.EQ.0)TD=TD/DELTD
        IF(ITS.EQ.1)THEN
         NTT=NTS-NT+1
         IF(KK.EQ.1)TD=TIMEPW(NTT)/F1
         IF(KK.GT.1)TD=TIMEOB(NTT)/F1
        ENDIF
       ENDIF
C
C---IF IHDH OR IHD HAVE BEEN SET TO 0, THEN PREVIOUS DRAWDOWN
C    WAS LESS THAN 1.0D-2; THUS, NO NEED TO CALCULATE DRAWDOWNS
C    FOR SMALLER TIMES (THAT IS, MINIMUM DRAWDOWN ALLOWED IS
C    1.0D-2)
C
C---IF CONFINED AQUIFER (IAQ=0), CALL LTST2
        IF(IAQ.EQ.0)THEN
         IF(IHDH.EQ.0)GOTO 35
         CALL LTST2(TD,HD)
         IF(DABS(HD).LT.1.0D-2)IHDH=0
        ENDIF
C
C---IF WATER-TABLE AQUIFER (IAQ=1), CALL LTST3
        IF(IAQ.EQ.1)THEN
         IF(IHD.EQ.0)GOTO 35
         CALL LTST3(TD,HD)
         IF(DABS(HD).LT.1.0D-2)IHD=0
        ENDIF
C
  35    IF(HD.LT.1.D-02)HD=0.0D0
C
        IF(IFORMAT.EQ.0)THEN
         TDRDSQ=TD/RDSQ
         TDPLOT(KK,NT)=TDRDSQ
         HDPLOT(KK,NT)=HD
        ENDIF
C
        IF(IFORMAT.GE.1)THEN
         RTD=F1*TD
         RHD=F2*HD
         TDPLOT(KK,NT)=RTD
         HDPLOT(KK,NT)=RHD
        ENDIF
C
C---END TIME LOOP FOR DRAWDOWN CURVE
  30   CONTINUE
C
C7d-WRITE TIME-DRAWDOWN CALCULATIONS TO RESULT FILE AND, FOR
C   DIMENSIONAL DATA, TO PLOT FILE
       DO 40 NT=1,NTS
       NTT=NTS-NT+1
       IF(IFORMAT.EQ.0)WRITE(IO,119)TDPLOT(KK,NTT),HDPLOT(KK,NTT)
       IF(IFORMAT.GE.1)THEN
        IF(IMEAS.EQ.0)WRITE(IO,120)TDPLOT(KK,NTT),HDPLOT(KK,NTT)
        IF(IMEAS.EQ.1)THEN
         IF(KK.EQ.1)THEN
          IF(XMEASPW(NT).EQ.0.0D0)RELERR=0.0D0
          IF(XMEASPW(NT).GT.0.0D0)
     2     RELERR=100.0D0*(XMEASPW(NT)-HDPLOT(KK,NTT))/XMEASPW(NT)
          IF(XMEASPW(NT).EQ.0.0D0)WRITE(IO,128)TDPLOT(KK,NTT),
     2     XMEASPW(NT),HDPLOT(KK,NTT)
          IF(XMEASPW(NT).GT.0.0D0)WRITE(IO,121)TDPLOT(KK,NTT),
     2     XMEASPW(NT),HDPLOT(KK,NTT),RELERR
         ENDIF
         IF(KK.GT.1)THEN
          IF(XMEASOB(NT).EQ.0.0D0)RELERR=0.0D0
          IF(XMEASOB(NT).GT.0.0D0)
     2     RELERR=100.0D0*(XMEASOB(NT)-HDPLOT(KK,NTT))/XMEASOB(NT)
          IF(XMEASOB(NT).EQ.0.0D0)WRITE(IO,128)TDPLOT(KK,NTT),
     2     XMEASOB(NT),HDPLOT(KK,NTT)
          IF(XMEASOB(NT).GT.0.0D0)WRITE(IO,121)TDPLOT(KK,NTT),
     2     XMEASOB(NT),HDPLOT(KK,NTT),RELERR
         ENDIF
        ENDIF
       ENDIF
C
       IF(IPLOT.EQ.1)THEN
        IF(IFORMAT.GE.1)THEN
         IF(ITS.GT.0)THEN
          IF(IMEAS.EQ.0)THEN
           IF(KK.EQ.1)THEN
            WRITE(IP,122)TDPLOT(KK,NTT),HDPLOT(KK,NTT)
           ENDIF
           IF(KK.GT.1)THEN
            WRITE(IP,122)TDPLOT(KK,NTT),HDPLOT(KK,NTT)
           ENDIF
          ENDIF
          IF(IMEAS.EQ.1)THEN
           IF(KK.EQ.1)THEN
            IF(XMEASPW(NT).EQ.0.0D0)RELERR=0.0D0
            IF(XMEASPW(NT).GT.0.0D0)
     2       RELERR=100.0D0*(XMEASPW(NT)-HDPLOT(KK,NTT))/XMEASPW(NT)
            IF(XMEASPW(NT).EQ.0.0D0)WRITE(IP,129)TDPLOT(KK,NTT),
     2       XMEASPW(NT),HDPLOT(KK,NTT)
            IF(XMEASPW(NT).GT.0.0D0)WRITE(IP,123)TDPLOT(KK,NTT),
     2       XMEASPW(NT),HDPLOT(KK,NTT),RELERR
           ENDIF
           IF(KK.GT.1)THEN
            IF(XMEASOB(NT).EQ.0.0D0)RELERR=0.0D0
            IF(XMEASOB(NT).GT.0.0D0)
     2       RELERR=100.0D0*(XMEASOB(NT)-HDPLOT(KK,NTT))/XMEASOB(NT)
            IF(XMEASOB(NT).EQ.0.0D0)WRITE(IP,129)TDPLOT(KK,NTT),
     2       XMEASOB(NT),HDPLOT(KK,NTT)
            IF(XMEASOB(NT).GT.0.0D0)WRITE(IP,123)TDPLOT(KK,NTT),
     2       XMEASOB(NT),HDPLOT(KK,NTT),RELERR
           ENDIF
          ENDIF
         ENDIF
        ENDIF
       ENDIF
C
C 
  40  CONTINUE
C
C7--FINISHED WITH CURVE KK, CONTINUE TO NEXT CURVE
  10  CONTINUE
C
C8--CALCULATE THEIS DRAWDOWNS FOR DIMENSIONLESS CURVES AND
C   WRITE ALL TIME-DRAWDOWN CALCULATIONS TO PLOT FILE FOR
C   TYPE-CURVE FORMATS (INCLUDING DIMENSIONAL)
      IF(IPLOT.EQ.1)THEN
       IF(IFORMAT.EQ.0)THEN
        TD=DELTD*TDLAST*RDSQ
        IF(IAQ.EQ.0)THEN
         TDY=TD
        ELSE
         TDY=TD*SIGMA
        ENDIF
C
C8a-CALCULATE THEIS DRAWDOWNS
        DO 45 NT=1,NTS
         HDT=0.0D0
         HDTY=0.0D0
         TD=TD/DELTD
         TDY=TDY/DELTD
C
         IF(TD.GE.1.0D-03) CALL LTST1(TD,HDT)
         IF(HDT.LT.1.0D-02) HDT=0.0D0
         IF(TDY.GE.1.0D-03) CALL LTST1(TDY,HDTY)
         IF(HDTY.LT.1.0D-02) HDTY=0.0D0
C
         TDRDSQT(NT)=TD/RDSQ
         TDRDSQTY(NT)=TDY/RDSQ
         HDTPLOT(NT)=HDT
         HDTYPLOT(NT)=HDTY
  45    CONTINUE
C
C8b-WRITE DIMENSIONLESS TIME-DRAWDOWN CALCULATIONS TO PLOT FILE
        NSTRIP=(NOBWC/5) + 1
        KK1=1
        KK2=5
        IF(KK2.GT.KKTOT) KK2=KKTOT
        DO 50 I=1,NSTRIP
         WRITE(IP,124)(WELLTXT(J),J=KK1,KK2)
        DO 55 NT=1,NTS
         NTT=NTS-NT+1
         WRITE(IP,125)TDRDSQT(NTT),HDTPLOT(NTT),
     2   TDRDSQTY(NTT),HDTYPLOT(NTT), (HDPLOT(K,NTT),K=KK1,KK2)
  55    CONTINUE
C
        KK1=KK1+5
        KK2=KK2+5
        IF(KK2.GT.KKTOT) KK2=KKTOT
  50    CONTINUE
C
       ENDIF
C
C8c-WRITE DIMENSIONAL TIME-DRAWDOWN CALCULATIONS TO PLOT FILE
       IF(IFORMAT.EQ.1)THEN
        IF(ITS.EQ.0)THEN
         NSTRIP=(NOBWC/5) + 1
         KK1=1
         KK2=5
         IF(KK2.GT.KKTOT) KK2=KKTOT
         DO 60 I=1,NSTRIP
          WRITE(IP,126)(WELLTXT(J),J=KK1,KK2)
         DO 65 NT=1,NTS
          NTT=NTS-NT+1
          WRITE(IP,127)TDPLOT(1,NTT),(HDPLOT(K,NTT),K=KK1,KK2)
  65     CONTINUE
C
         KK1=KK1+5
         KK2=KK2+5
         IF(KK2.GT.KKTOT) KK2=KKTOT
  60     CONTINUE
C
        ENDIF
       ENDIF
C
      ENDIF
C
C8--FINISHED CALCULATING THEIS DRAWDOWNS AND WRITING TO PLOT FILE
C
C---FORMAT STATEMENTS
  100 FORMAT(/,3X,'DIMENSIONLESS TIME   DIMENSIONLESS DRAWDOWN',
     2/,7X,'(TDRDSQ)',18X,'(HD)',/,3X,'------------------',
     3'   ----------------------')
  101 FORMAT(/,17X,'CALCULATED',/,6X,'TIME        DRAWDOWN',
     2/,6X,'----       ----------')
  102 FORMAT(/,48X,'RELATIVE',/,18X,'MEASURED',6X,'CALCULATED',7X,
     2'ERROR',/,6X,'TIME        DRAWDOWN       DRAWDOWN     ',
     3'  (PERCENT)'/,6X,'----       ----------     ----------    ',
     4' ---------- ')
  103 FORMAT(/,/,9X,'****   PUMPED WELL   ****')
  104 FORMAT(/,5X,'TIME           CALCDD')
  105 FORMAT(/,5X,'TIME          MEASDD         CALCDD         ',
     2'RELERR')
  106 FORMAT(/,/,/,1X,'*** OBSERVATION-WELL CHARACTERISTICS AND',
     2' CALCULATED DRAWDOWN ***',/)
  107 FORMAT(/,3X,'EITHER IOWS OR IDPR IS INCORRECT.  PROGRAM STOPPED.')
  108 FORMAT(/,3X,'AN OBSERVATION-WELL VARIABLE (R, Z1, Z2, ZP, WDP,',
     2' RP, OR XLL) IS LESS',/,3X,'THAN ZERO.  PROGRAM STOPPED.')
  109 FORMAT(/,2X,'Z2(I)-Z1(I) DOES NOT EQUAL SATURATED',
     2' THICKNESS SPECIFIED FOR AQUIFER.',/,2X,'MODIFY Z2(I),',
     3' Z1(I), OR BB. PROGRAM STOPPED.')
  110 FORMAT(/,3X,'INFORMATION ON OBSERVATION-WELL TIME-DRAWDOWN DATA',
     2' (NTSOB, IRUN,',/,3X,'OR TIMEOB(I)) IS NOT CORRECT.  PROGRAM',
     3' STOPPED.')
  111 FORMAT(/,/,13X,'****   DRAWDOWN NOT CALCULATED   ****')
  112 FORMAT(/,/,9X,'****   OBSERVATION WELL OR PIEZOMETER',I3,
     2 2X,'****')
  113 FORMAT(/,/,3X,'PARTIALLY PENETRATING OBSERVATION WELL')
  114 FORMAT(/,/,3X,'FULLY PENETRATING OBSERVATION WELL')
  115 FORMAT(/,/,3X,'OBSERVATION PIEZOMETER')
  116 FORMAT(/,/,3X,'DISTANCE FROM',/,5X,'CENTER OF',29X,
     2 'DELAYED RESPONSE',/,4X,'PUMPED WELL',10X,'Z1',10X,'Z2',
     3 9X,'FACTOR',/,3X,'---------------------',
     4 '-----------------------------------',/,5X,D9.3,7X,D9.3,
     5 3X,D9.3,4X,D9.3)
  117 FORMAT(/,/,3X,'DISTANCE FROM',/,5X,'CENTER OF',16X,
     2 'DELAYED RESPONSE',/,4X,'PUMPED WELL',8X,'ZP',10X,'FACTOR',/,
     3 3X,'-------------------------------------------',/,5X,D9.3,
     4 5X,D9.3,5X,D9.3)
  118 FORMAT(/,/,3X,'DRAWDOWN CALCULATED FOR BETA = ',D12.3)
  119 FORMAT(5X,D11.4,12X,D11.4)
  120 FORMAT(1X,D11.4,4X,D11.4)
  121 FORMAT(1X,D11.4,4X,D11.4,4X,D11.4,4X,D11.4)
  122 FORMAT(1X,E11.4,4X,E11.4)
  123 FORMAT(1X,E11.4,4X,E11.4,4X,E11.4,4X,E11.4)
  124 FORMAT(/,'    TDRDSQ     HDT     TDYRDSQ     HDTY',2X,
     2 5(4X,A6))
  125 FORMAT(1X,9(1X,E9.3))
  126 FORMAT(/,'    TIME',2X,5(4X,A6))
  127 FORMAT(1X,6(1X,E9.3))
  128 FORMAT(1X,D11.4,4X,D11.4,4X,D11.4,8X,'****')
  129 FORMAT(1X,E11.4,4X,E11.4,4X,E11.4,8X,'****')
C---Version 1.1: add FORMAT statements:
  130 FORMAT(/,/,3X,'SPECIFIED TOP OF SCREENED INTERVAL OF',
     2' OBSERVATION WELL (Z1) IS BELOW BOTTOM',/,5X,' OF',
     3' SCREENED INTERVAL (Z2). PROGRAM STOPPED.')
  131 FORMAT(/,/,3X,'SPECIFIED VALUE OF TOP (Z1) OR BOTTOM (Z2)',
     2' OF SCREENED INTERVAL OF OBSERVATION WELL IS',/,5X,
     3' GREATER THAN SPECIFIED THICKNESS OF AQUIFER (BB).',
     4' PROGRAM STOPPED.')
  132 FORMAT(/,/,3X,'SPECIFIED VALUE OF PIEZOMETER LOCATION (ZP)',
     2' IS GREATER THAN SPECIFIED THICKNESS OF AQUIFER (BB).',/,5X,
     3' PROGRAM STOPPED.')
  133 FORMAT(/,/,3X,'SPECIFIED VALUE OF BOTTOM OF SCREENED',
     2' INTERVAL OF OBSERVATION WELL (Z2) DOES NOT EQUAL',/,5x,
     3' THICKNESS OF AQUIFER (BB). Z1 SHOULD EQUAL 0.0 AND Z2',
     4' SHOULD EQUAL BB FOR A FULLY PENETRATING WELL.',/,5X,
     5' PROGRAM STOPPED.')
C
C9--CLOSE INPUT/RESULT/PLOT FILES, STOP, AND END
      CLOSE(UNIT=IN)
      CLOSE(UNIT=IO)
      IF(IPLOT.EQ.1)CLOSE(UNIT=IP)
      STOP
 1000 CALL RDERR(IO,STRING,ILINE)
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE OFILE                    *
C      *                                                      *
C      *        VERSION 1.3 CURRENT AS OF 06/29/2012          *
C      *                                                      *
C       ******************************************************
C
C10-SUBROUTINE OFILE OPENS INPUT, RESULT, AND PLOT FILES
C
      SUBROUTINE OFILE(IPLOT)
C---SPECIFICATIONS
      CHARACTER*50 IFNAME, OFNAME, PFNAME
      INTEGER IN, IO, IP, N, IPLOT
      COMMON /IOUNIT/ IN,IO,IP
C
      IN = 15
      IO = 16
      IP = 17
C
C---Version 1.1: add WTAQ banner:
      WRITE(*,8)
C
C---READ INPUT, RESULT, AND PLOT FILE NAMES
   10 WRITE(*,2)
      READ(*,5) IFNAME
      N=LENCHR(IFNAME)
      IF(N.LT.1) GO TO 10
      OPEN(IN,FILE=IFNAME,STATUS='OLD')
C
   11 WRITE(*,3)
      READ(*,5) OFNAME
      N=LENCHR(OFNAME)
      IF(N.LT.1) GO TO 11
      OPEN(IO,FILE=OFNAME)
C
      WRITE(*,4)
      READ(*,5) PFNAME
      N=LENCHR(PFNAME)
      IF(N.LT.1)THEN
       IPLOT=0
       WRITE(*,6)
      ELSE
       IPLOT=1
       OPEN(IP,FILE=PFNAME)
      ENDIF
C
      WRITE(*,7)
C
C---FORMAT STATEMENTS
    2 FORMAT(3X,'Enter name of file containing input data:')
    3 FORMAT(3X,'Enter name of file for program results:')
    4 FORMAT(3X,'Enter name of plot file (return for no plot file):')
    5 FORMAT(A50)
    6 FORMAT(/,3X,'No plot file specified. Results will not be written',
     1' to a plot file.')
    7 FORMAT(/,3X,'File names have been read.')
C---Version 1.1: add FORMAT statement:
    8 FORMAT(10X,'    WTAQ version 1.3,   June 29, 2012',/,
     1 3X, 'Computer Program for Calculating Drawdown in a Confined',/,
     2 7X, ' or Water-Table Aquifer with Axial-Symmetric Flow',/,
     3 22X,' to a Pumped Well',/)
C
C---RETURN AND END
      RETURN
      END
C
C       ******************************************************
C      *                                                      *
C      *                    FUNCTION LENCHR                   *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C11-FUNCTION LENCHR CALCULATES THE LENGTH OF A CHARACTER STRING
C   (CODE FROM R. STEVE REGAN, USGS)
C
      INTEGER FUNCTION LENCHR
     I                       ( STRING )
C
      CHARACTER*(*) STRING
C
C     + + + ARGUMENT DEFINITIONS + + +
C     STRING - Input string to determine length of
C
C     + + + LOCAL VARIABLES + + +
      INTEGER MAX, I
C
C     + + + INTRINSICS + + +
      INTEGER LEN
      INTRINSIC LEN
C
C     + + + END SPECIFICATIONS + + +
C
      MAX = LEN(STRING)
      DO 10 I = MAX, 1, -1
        IF (STRING(I:I).NE.' ') THEN
          LENCHR = I
          GOTO 20
        ENDIF
   10 CONTINUE
      LENCHR = 0
C
   20 RETURN
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                 SUBROUTINE DATAPREP                  *
C      *                                                      *
C      *        VERSION 1.3 CURRENT AS OF 06/29/2012          *
C      *                                                      *
C       ******************************************************
C
C12-SUBROUTINE DATAPREP READS MOST INPUT DATA FROM THE INPUT FILE,
C   WRITES THIS DATA TO THE RESULT FILE, AND PREPARES INPUT DATA
C   FOR USE IN MAIN PROGRAM
      SUBROUTINE DATAPREP
C---SPECIFICATIONS
C
C---THE PARAMETER STATEMENT BELOW SPECIFIES THE FOLLOWING PROGRAM
C   DIMENSIONS:
C    IMAXX1 = MAXIMUM NUMBER OF TIME-DRAWDOWN CURVES TO BE GENERATED
C             (THE FIRST CURVE IS ALWAYS THE PUMPED WELL, EVEN WHEN
C             CURVES ARE NOT CALCULATED AT THE PUMPED WELL)
C    IMAXX2 = MAXIMUM NUMBER OF USER SPECIFIED TIMES OR MEASURED
C             DRAWDOWNS AT THE PUMPED WELL OR OBSERVATION WELLS
C
      PARAMETER (IMAXX1=25,IMAXX2=200)
C
      IMPLICIT DOUBLE PRECISION (A-H, O-Z)
      DIMENSION ALPHA(5),GAMMA(5)
      DIMENSION TIMEPW(IMAXX2),XMEASPW(IMAXX2)
      CHARACTER STRING*80,TITLE*70,FORMAT*25,AQTYPE*11,
     2 FORMATTXT*27,AQTYPETXT*20
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ IPWD,IRUN,IPWS,NOBWC,IOWS,IDPR
      COMMON /PAR2/ NGAMMA,IDRA,NS,KK,NMAX,NTMS
      COMMON /PAR3/ IFORMAT,IAQ,NLC,NOX
      COMMON /PAR4/ ITS,IMEAS,NTSPW
      COMMON /PAR5/ BB,HKR,XKD,SS,SY,RW,QQ
      COMMON /PAR6/ BETAW,SIGMA,GAMMA
      COMMON /PAR7/ RERRNR,RERRSUM,TDLAST,TLAST
      COMMON /PAR8/ R,ZP,Z1,Z2,WDP
      COMMON /PAR9/ V(20),XLN2,EXPMAX
      COMMON /PAR10/ RD,ZD,ZD1,ZD2
      COMMON /PAR11/ XLD,XDD,WD,SW
      COMMON /PAR12/ TIMEPW,XMEASPW
C
C12a-WRITE PROGRAM BANNER TO RESULT FILE
      CALL BANNER(IO)
C
C
C12b-READ AND PREPARE INPUT DATA
C
C---READ TITLE
      READ(IN,'(A70)') STRING
      ILINE=1
      READ(STRING,100,ERR=1000) TITLE
C
C---READ AND TEST TYPE OF ANALYSIS FORMAT
      IFORMAT=2
      READ(IN,'(A25)') STRING
      ILINE=2
      READ(STRING,101,ERR=1000) FORMAT 
      IF(FORMAT.EQ.'TYPE CURVE')IFORMAT=0
      IF(FORMAT.EQ.'DIMENSIONAL')IFORMAT=1
C
C---IF IFORMAT STILL EQUALS 2, UNRECOGNIZED FORMAT; STOP
      IF(IFORMAT.EQ.2)THEN
        WRITE(IO,102)
        STOP
      ENDIF
C
C---READ AND TEST AQUIFER TYPE
      IAQ=2
      READ(IN,'(A11)') STRING
      ILINE=3
      READ(STRING,103,ERR=1000) AQTYPE
      IF(AQTYPE.EQ.'CONFINED')IAQ=0
      IF(AQTYPE.EQ.'WATER TABLE')IAQ=1
C
C---IF IAQ STILL EQUALS 2, UNRECOGNIZED AQUIFER TYPE; STOP
      IF(IAQ.EQ.2)THEN
        WRITE(IO,104)
        STOP
      ENDIF
C
C---READ AND TEST AQUIFER PROPERTIES
      READ(IN,'(A80)') STRING
      ILINE=4
      IF(IFORMAT.EQ.0)READ(STRING,*,ERR=1000) BB, XKD, SIGMA
      IF(IFORMAT.GE.1)READ(STRING,*,ERR=1000) BB, HKR, HKZ, SS, SY
C
      IF(BB.LE.0.0D0)THEN
       WRITE(IO,105)
       STOP
      ENDIF
      IF(IFORMAT.EQ.0)THEN
C---SIGMA.LE.0.0D0 changed to LT.0.0D0 for version 1.3
       IF(SIGMA.LT.0.0D0.OR.XKD.LE.0.0D0)THEN
        WRITE(IO,105)
        STOP
       ENDIF
      ENDIF
      IF(IFORMAT.GE.1)THEN
       IF(HKR.LE.0.0D0.OR.HKZ.LE.0.0D0)THEN
        WRITE(IO,105)
        STOP
       ENDIF
       IF(SS.LE.0.0D0)THEN
        WRITE(IO,105)
        STOP
       ENDIF
       AT=HKR*BB
       XKD=HKZ/HKR
       ASC=SS*BB
       IF(IAQ.EQ.1)THEN
        IF(SY.LE.0.0D0)THEN
         WRITE(IO,105)
         STOP
        ENDIF
        SIGMA=ASC/SY
       ENDIF
      ENDIF
C
C---SIGMA = 0 FOR CONFINED AQUIFERS
      IF(IAQ.EQ.0)SIGMA=0.0D0
C
C---READ AND TEST DRAINAGE PROPERTIES
      READ(IN,'(A80)') STRING
      ILINE=5
      IF(IFORMAT.EQ.0)READ(STRING,*,ERR=1000)IDRA, NGAMMA
      IF(IFORMAT.GE.1)READ(STRING,*,ERR=1000)IDRA, NALPHA
C
      IF(IDRA.LT.0)THEN
       WRITE(IO,106)
       STOP
      ENDIF
      IF(NGAMMA.LT.0.OR.NALPHA.LT.0)THEN
       WRITE(IO,106)
       STOP
      ENDIF
      IF(NGAMMA.GT.5.OR.NALPHA.GT.5)THEN
       WRITE(IO,106)
       STOP
      ENDIF
C
      IF(IDRA.EQ.0)NGAMMA=0
      IF(IDRA.EQ.0)NALPHA=0
      IF(IAQ.EQ.0)IDRA=0
      IF(IAQ.EQ.0)NGAMMA=0
      IF(IAQ.EQ.0)NALPHA=0
C
      READ(IN,'(A80)')STRING
      ILINE=6
      IF(IDRA.EQ.1)THEN
       IF(IFORMAT.EQ.0)READ(STRING,*,ERR=1000)(GAMMA(I),I=1,NGAMMA)
       IF(IFORMAT.GE.1)READ(STRING,*,ERR=1000)(ALPHA(I),I=1,NALPHA)
C
C12c-CONVERT DIMENSIONAL ALPHAS TO DIMENSIONLESS GAMMAS
       IF(IFORMAT.GE.1)THEN
        DO 5 I=1,NALPHA
         GAMMA(I)=ALPHA(I)*BB*SY/HKZ
  5     CONTINUE
        NGAMMA=NALPHA
       ENDIF
       DO 10 I=1,NGAMMA
        IF(GAMMA(I).LT.0.0D0)THEN
         WRITE(IO,106)
         STOP
        ENDIF
 10     CONTINUE
      ENDIF
C
C---READ AND TEST TIME-STEP INFORMATION
      IF(IFORMAT.LE.1)THEN
       READ(IN,'(A80)') STRING
       IF(IFORMAT.EQ.0)THEN
        ILINE=7
        READ(STRING,*,ERR=1000) TDLAST, NLC, NOX
       ENDIF
       IF(IFORMAT.EQ.1)THEN
        ILINE=8
        READ(STRING,*,ERR=1000) ITS, IMEAS
        READ(IN,'(A80)') STRING
        ILINE=9
        READ(STRING,*,ERR=1000) TLAST, NLC, NOX
       ENDIF
      ENDIF
C
C---IF IFORMAT = 0 (TYPE CURVE), LOG-TYPE ANALYSIS. NO USER-
C    SPECIFIED TIMES OR MEASURED DRAWDOWN DATA
      IF(IFORMAT.EQ.0)THEN
       ITS=0
       IMEAS=0
      ENDIF
C
      IF(TDLAST.LT.0.0D0.OR.TLAST.LT.0.0D0)THEN
       WRITE(IO,107)
       STOP
      ENDIF
      IF(NLC.LT.0.OR.NOX.LT.0)THEN
       WRITE(IO,107)
       STOP
      ENDIF
      IF(ITS.LT.0.OR.IMEAS.LT.0)THEN
       WRITE(IO,107)
       STOP
      ENDIF

C---READ AND TEST PROGRAM-SOLUTION VARIABLES
      READ(IN,'(A80)') STRING
      ILINE=10
      READ(STRING,*,ERR=1000) RERRNR, RERRSUM, NMAX, NTMS, NS 
      IF(RERRNR.LT.0.0D0.OR.RERRSUM.LT.0.0D0)THEN
       WRITE(IO,108)
       STOP
      ENDIF
      IF(NMAX.LT.0.OR.NTMS.LT.0)THEN
       WRITE(IO,108)
       STOP
      ENDIF
      IF(NS.LT.0)THEN
       WRITE(IO,108)
       STOP
      ENDIF
C
C---READ AND TEST PUMPED-WELL INFORMATION
      READ(IN,'(A80)') STRING
      ILINE=11
      READ(STRING,*,ERR=1000) IPWS, IPWD
C
      IF(IPWS.LT.0.OR.IPWS.GT.1)THEN
       WRITE(IO,109)
       STOP
      ENDIF
      IF(IPWD.LT.0.OR.IPWD.GT.1)THEN
       WRITE(IO,109)
       STOP
      ENDIF
C
      READ(IN,'(A80)') STRING
      ILINE=12
      IF(IFORMAT.EQ.0)THEN
      READ(STRING,*,ERR=1000) RW, ZPD, ZPL, WD, SW
      ENDIF
      IF(IFORMAT.GE.1)THEN
      READ(STRING,*,ERR=1000) QQ, RW, RC, ZPD, ZPL, SW
      ENDIF
C
      IF(RW.LT.0.0D0.OR.RC.LT.0.0D0)THEN
       WRITE(IO,110)
       STOP
      ENDIF
      IF(ZPD.LT.0.0D0.OR.ZPL.LT.0.0D0)THEN
       WRITE(IO,110)
       STOP
      ENDIF
C---Version 1.1: add tests for partially-penetrating wells:
      IF(IPWS.EQ.0)THEN
       IF(ZPD.GE.ZPL)THEN
        WRITE(IO,146)
        STOP
       ENDIF
       IF(ZPD.GT.BB.OR.ZPL.GT.BB)THEN
        WRITE(IO,147)
        STOP
       ENDIF
      ENDIF
C
      IF(WD.LT.0.0D0.OR.SW.LT.0.0D0)THEN
       WRITE(IO,110)
       STOP
      ENDIF
      IF(QQ.LT.0.0D0)THEN
       WRITE(IO,110)
       STOP
      ENDIF
C
C12d-CALCULATE PUMPING-WELL DIMENSIONLESS PARAMETERS 
      RWD=RW/BB
      BETAW=XKD*(RWD*RWD)
      IF(IPWD.EQ.0)WD=0.0D0
      IF(IPWD.EQ.1)THEN
       IF(IFORMAT.GE.1)WD=((RC/RW)**2)/(2.0D0*SS*(ZPL-ZPD))
      ENDIF
      IF(IPWS.EQ.0)THEN
       XDD=ZPD/BB
       XLD=ZPL/BB
      ENDIF
      IF(IPWS.EQ.1)THEN
C---Version 1.1: add additional test:
        IF(ZPL.NE.BB)THEN
         WRITE(IO,148)
         STOP
        ENDIF
C
       BCALC=ZPL-ZPD
       IF(BCALC.NE.BB)THEN
        WRITE(IO,111)
        STOP
       ENDIF
      ENDIF
      IF(IPWS.EQ.1)THEN
       XDD=0.0D0
       XLD=1.0D0
      ENDIF
C
C---READ AND TEST PUMPED-WELL TIME-DRAWDOWN DATA
C
C---DEFAULT IS TO CALCULATE PUMPED WELL DRAWDOWN CURVES
      IRUN=1
C
      IF(IFORMAT.GE.1)THEN
       IF(ITS.EQ.1)THEN
        READ(IN,'(A80)') STRING
        ILINE=13
        READ(STRING,*,ERR=1000) NTSPW, IRUN
        IF(NTSPW.LT.0)THEN
         WRITE(IO,112)
         STOP
        ENDIF
        IF(IRUN.LT.0.OR.IRUN.GT.1)THEN
         WRITE(IO,112)
         STOP
        ENDIF
        IF(NTSPW.EQ.0)THEN
         IRUN=0
         GOTO 35
        ENDIF
        IF(IMEAS.EQ.0)THEN
         DO 20 ID=1,NTSPW
          READ(IN,'(A80)') STRING
          ILINE=14
          READ(STRING,*,ERR=1000) TIMEPW(ID)
  20     CONTINUE
        ENDIF
        IF(IMEAS.EQ.1)THEN
         DO 25 ID=1,NTSPW
          READ(IN,'(A80)') STRING
          ILINE=14
          READ(STRING,*,ERR=1000) TIMEPW(ID), XMEASPW(ID)
  25     CONTINUE
        ENDIF
        DO 30 ID=1,NTSPW
         IF(TIMEPW(ID).LT.0.0D0)THEN
          WRITE(IO,112)
          STOP
         ENDIF
  30    CONTINUE
       ENDIF
      ENDIF
C
C---READ AND TEST OBSERVATION-WELL INFORMATION
  35  READ(IN,'(A80)') STRING
      ILINE=15
      READ(STRING,*,ERR=1000) NOBWC
C
      IF(NOBWC.LT.0.OR.NOBWC.GT.(IMAXX1-1))THEN
       WRITE(IO,113)(IMAXX1-1)
       STOP
      ENDIF
C
C12e-WRITE INPUT DATA TO RESULT FILE
C
C---TITLE 
      WRITE(IO,114)TITLE
C
C---ANALYSIS TYPE AND AQUIFER TYPE
      IF(IFORMAT.EQ.0)FORMATTXT='TYPE-CURVE FORMAT'
      IF(IFORMAT.EQ.1)FORMATTXT='DIMENSIONAL FORMAT'
      IF(IAQ.EQ.0)AQTYPETXT='CONFINED AQUIFER'
      IF(IAQ.EQ.1)AQTYPETXT='WATER-TABLE AQUIFER'
      WRITE(IO,115)FORMATTXT,AQTYPETXT
C
C---HYDRAULIC PROPERTIES
      WRITE(IO,116)
C
      IF(IFORMAT.EQ.0)THEN
       WRITE(IO,117)BB
       WRITE(IO,118)XKD
       IF(IAQ.EQ.1)WRITE(IO,119)SIGMA
      ENDIF
C
      IF(IFORMAT.GE.1)THEN
       WRITE(IO,117)BB
       WRITE(IO,120)HKR
       WRITE(IO,121)HKZ
       WRITE(IO,118)XKD
       WRITE(IO,122)AT
       WRITE(IO,123)SS
       IF(IAQ.EQ.1)WRITE(IO,124)SY
       WRITE(IO,125)ASC
       IF(IAQ.EQ.1)WRITE(IO,119)SIGMA
      ENDIF
C
C---DRAINAGE PROPERTIES
      IF(IAQ.EQ.1)THEN
       IF(IDRA.EQ.0)WRITE(IO,126)IDRA
       IF(IDRA.EQ.1)THEN
        WRITE(IO,127)IDRA
        IF(IFORMAT.EQ.0)WRITE(IO,128)(GAMMA(I),I=1,NGAMMA)
        IF(IFORMAT.GT.0)THEN
         WRITE(IO,129)(ALPHA(I),I=1,NALPHA)
         WRITE(IO,128)(GAMMA(I),I=1,NGAMMA)
        ENDIF
       ENDIF
      ENDIF
C
C---TIME-STEP AND PROGRAM-SOLUTION VARIABLES
      IF(IFORMAT.EQ.0)THEN
       WRITE(IO,130)
       WRITE(IO,131)TDLAST,NLC,NOX
      ENDIF
      IF(IFORMAT.GE.1)THEN
       IF(ITS.EQ.0)THEN
        WRITE(IO,132)
        WRITE(IO,131)TLAST,NLC,NOX
       ENDIF
       IF(ITS.EQ.1)THEN
        IF(IMEAS.EQ.0)WRITE(IO,133)
        IF(IMEAS.EQ.1)WRITE(IO,134)
       ENDIF
      ENDIF
      WRITE(IO,135)
      WRITE(IO,136)RERRNR,RERRSUM,NMAX,NTMS,NS
C
C---PUMPING-WELL INFORMATION
      WRITE(IO,137)
      IF(IPWD.EQ.0)WRITE(IO,138)IPWD
      IF(IPWD.EQ.1)WRITE(IO,139)IPWD
      IF(IPWS.EQ.0)WRITE(IO,140)IPWS
      IF(IPWS.EQ.1)WRITE(IO,141)IPWS
      IF(IFORMAT.GE.1)WRITE(IO,142)QQ
      WRITE(IO,143)
      WRITE(IO,144)RW,ZPD,ZPL,WD,SW
      WRITE(IO,145)BETAW
C
C---FORMAT STATEMENTS
  100 FORMAT(A70)
  101 FORMAT(A25)
  102 FORMAT(/,/,3X,'ANALYSIS FORMAT (LINE 2) IS INVALID.',
     2' PROGRAM STOPPED.')
  103 FORMAT(A11)
  104 FORMAT(/,/,3X,'AQUIFER TYPE IS INVALID. PROGRAM STOPPED.')
  105 FORMAT(/,3X,'A HYDRAULIC PROPERTY OF THE AQUIFER (INPUT LINE',
     2 ' 4) IS LESS THAN OR',/,3X,' EQUAL TO ZERO.',
     3 ' PROGRAM STOPPED.')
  106 FORMAT(/,3X,'A DRAINAGE VARIABLE OR PROPERTY (IDRA, NGAMMA,',
     2' NALPHA, GAMMA(I), OR',/,3X,'ALPHA(I)) IS NOT CORRECT.',
     3'  PROGRAM STOPPED.')
  107 FORMAT(/,3X,'A TIME-STEP VARIABLE (TDLAST, TLAST, NLC, NOX,',
     2'  ITS, OR IMEAS) IS LESS THAN',/,3X,' ZERO.  PROGRAM STOPPED.')
  108 FORMAT(/,3X,'A PROGRAM-SOLUTION VARIABLE (RERRNR, RERRSUM, NMAX,',
     2' NTMS, OR NS) IS LESS',/,3X,'THAN ZERO.  PROGRAM STOPPED.')
  109 FORMAT(/,3X,'EITHER IPWS OR IPWD IS NOT EQUAL TO 0 OR 1',
     2'  PROGRAM STOPPED.')
  110 FORMAT(/,3X,'A PUMPING-WELL VARIABLE (RW, RC, ZPD, ZPL, QQ, WD,',
     2' OR SW) IS LESS',/,3X,'THAN ZERO.  PROGRAM STOPPED.')
  111 FORMAT(/,2X,'ZPL-ZPD DOES NOT EQUAL INITIAL SATURATED THICKNESS',
     2' SPECIFIED FOR',/,2X,'AQUIFER. MODIFY ZPD, ZPL, OR BB.',
     3' PROGRAM STOPPED.')
  112 FORMAT(/,3X,'INFORMATION ON PUMPED-WELL TIME-DRAWDOWN DATA',
     2' (NTSPW, IRUN, OR TIMEPW(I))',/,3X,'IS NOT CORRECT.  PROGRAM',
     3' STOPPED.')
  113 FORMAT(/,2X,'SPECIFIED VALUE OF NOBWC IS LESS THAN ZERO OR ',
     2 'GREATER THAN',I3,'. NOBWC ',/,2X,'MUST BE LESS THAN OR EQUAL',
     3' TO (IMAXX1-1). IMAXX1 IS SPECIFIED IN THE',/,2X,'COMPUTER',
     4' CODE. REDUCE THE NUMBER OF OBSERVATION WELLS OR PIEZOMETERS',
     5 /,2X,'OR INCREASE THE VALUE OF IMAXX1 IN THE CODE.  PROGRAM',
     6 ' STOPPED.')
  114 FORMAT(3X,A70)
  115 FORMAT(/,/,3X,A27,5X,A20)
  116 FORMAT(/,/,/,15X,'*** AQUIFER HYDRAULIC PROPERTIES ***',/)
  117 FORMAT(2X,' SATURATED THICKNESS (BB): ',8X,D12.3,
     2' (units of length)')
  118 FORMAT(2X,' RATIO OF VERTICAL TO HORIZONTAL',/,3X,
     2' HYDRAULIC CONDUCTIVITY (XKD): ',3X,D12.3,' (dimensionless)')
  119 FORMAT(2X,' RATIO OF STORATIVITY TO',/,3X,
     2' SPECIFIC YIELD (SIGMA): ',9X,D12.3,' (dimensionless)')
  120 FORMAT(2X,' HORIZONTAL HYDRAULIC',/,3X,' CONDUCTIVITY (HKR): ',
     2 13X,D12.3,' (units of length per time)')
  121 FORMAT(2X,' VERTICAL HYDRAULIC',/,3x,' CONDUCTIVITY (HKZ): '
     2 13x,D12.3,' (units of length per time)')
  122 FORMAT(2X,' CALCULATED TRANSMISSIVITY: ',7X,D12.3,
     2' (units of length squared',/,51X,'per time)')
  123 FORMAT(2X,' SPECIFIC STORAGE (SS): ',11X,D12.3,
     2' (units of inverse length)')
  124 FORMAT(2X,' SPECIFIC YIELD (SY): ',13X,D12.3,
     2' (dimensionless)')
  125 FORMAT(2X,' CALCULATED STORATIVITY: ',10X,D12.3,
     2' (dimensionless)')
  126 FORMAT(2X,' DRAINAGE AT WATER TABLE (IDRA): ',3X,I3,
     2' (instantaneous)')
  127 FORMAT(2X,' DRAINAGE AT WATER TABLE (IDRA): ',3X,I3,
     2' (delayed)')
  128 FORMAT(2X,' DIMENSIONLESS DRAINAGE PARAMETER(S) (GAMMAS): ',/,
     2 3X,5(1PD11.2))
  129 FORMAT(2X,' DRAINAGE PARAMETER(S) (ALPHAS) (units of inverse',
     2' length):',/,3X,5(1PD11.2))
  130 FORMAT(/,/,/,16X,'*** PROGRAM SOLUTION VARIABLES ',
     2' ***',/,/,4X,'LARGEST VALUE',7X,'NUMBER OF',7X,'DRAWDOWN',
     3' CALCULATIONS',/,3X,'OF TIME (TDLAST)',3X,'LOG CYCLES',
     4' (NLC)',4X,'PER LOG CYCLE (NOX)',/,3X,'----------------',
     5'--------------------------------------------')
  131 FORMAT(7X,D9.3,11X,I2,18X,I2)
  132 FORMAT(/,/,/,16X,'*** PROGRAM SOLUTION VARIABLES ',
     2' ***',/,/,4X,'LARGEST VALUE',7X,'NUMBER OF',7X,'DRAWDOWN',
     3' CALCULATIONS',/,3X,'OF TIME (TLAST)',4X,'LOG CYCLES',
     4' (NLC)',4X,'PER LOG CYCLE (NOX)',/,3X,'----------------',
     5'--------------------------------------------')
  133 FORMAT(/,/,/,16X,'*** PROGRAM SOLUTION VARIABLES ',
     2' ***',/,/,3X,'USER-SPECIFIED TIMES; MEASURED DRAWDOWN',
     3' DATA NOT SPECIFIED')
  134 FORMAT(/,/,/,16X,'*** PROGRAM SOLUTION VARIABLES ',
     2' ***',/,/,3X,'USER-SPECIFIED TIMES; MEASURED DRAWDOWN',
     3' DATA SPECIFIED')
  135 FORMAT(/,/,5X,'RERRNR',6X,'RERRSUM',7X,'NMAX',7X,'NTMS',
     2 5X,'NS',/,3X,'------------------------------------------',
     3 '--------')
  136 FORMAT(4X,D9.3,3X,D9.3,4X,I5,6X,I5,6X,I2)
  137 FORMAT(/,/,/,3X,'*** PUMPED-WELL CHARACTERISTICS AND',
     2 ' CALCULATED DRAWDOWN ***',/)
  138 FORMAT(3X,'WELL-DIAMETER TYPE (IPWD):',11X,I1,
     2' (infinitesimal diameter)')
  139 FORMAT(3X,'WELL-DIAMETER TYPE (IPWD):',11X,I1,
     2 ' (finite diameter)')
  140 FORMAT(3X,'SCREENED INTERVAL (IPWS):',12X,I1,
     2' (partially penetrating)')
  141 FORMAT(3X,'SCREENED INTERVAL (IPWS):',12X,I1,
     2' (fully penetrating)')
  142 FORMAT(3X,'PUMPING RATE OF WELL (QQ):',9X,D11.3,
     2' (cubic length per time)')
  143 FORMAT(/,19X,'SCREENED INTERVAL',4X,'WELL BORE',3X,'WELL BORE',
     2/,4X,'WELL RADIUS',6X,'ZPD',6X,'ZPL',8X,'STORAGE',6X,'SKIN',
     3/,3X,'----------------------------------------------------------')
  144 FORMAT(5X,D8.2,5X,D8.2,2X,D8.2,4X,D8.2,4X,D8.2)
  145 FORMAT(/,/,3X,'BETAW = ',D12.3)
C---Version 1.1: add FORMAT statements:
  146 FORMAT(/,/,3X,'SPECIFIED TOP OF SCREENED INTERVAL OF PUMPED WELL',
     2' (ZPD) IS BELOW BOTTOM',/,12X,' OF SCREENED INTERVAL (ZPL).',
     3' PROGRAM STOPPED.')
  147 FORMAT(/,/,3X,'SPECIFIED VALUE OF TOP (ZPD) OR BOTTOM (ZPL)',
     2' OF SCREENED INTERVAL OF PUMPED WELL',/,5X,' IS GREATER',
     3' THAN SPECIFIED THICKNESS OF AQUIFER (BB).',
     4' PROGRAM STOPPED.')
  148 FORMAT(/,/,3X,'SPECIFIED VALUE OF BOTTOM OF SCREENED',
     2' INTERVAL OF PUMPED WELL (ZPL) DOES NOT EQUAL',/,5X,
     3' THICKNESS OF AQUIFER (BB). ZPD SHOULD EQUAL 0.0 AND ZPL',
     4' SHOULD EQUAL BB FOR A',/,5X,
     5' FULLY PENETRATING WELL. PROGRAM STOPPED.')
C
      RETURN
C---CALL RDERR FOR INPUT READ ERRORS
 1000 CALL RDERR(IO,STRING,ILINE)
      END
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE BANNER                   *
C      *                                                      *
C      *        VERSION 1.3 CURRENT AS OF 06/29/2011          *
C      *                                                      *
C       ******************************************************
C
C13-SUBROUTINE BANNER WRITES A PROGRAM BANNER TO RESULT FILE
      SUBROUTINE BANNER(IO)
      WRITE(IO,100)
 100  FORMAT(/,10X,
     2'      *****************************************************',/,
     3 10X,
     4'      *                                                   *',/,
     5 10X,
     6'      *         ****  U.S. GEOLOGICAL SURVEY  ****        *',/,
     7 10X,
     8'      *                                                   *',/,
     9 10X,
     &'      *           **** WTAQ: PROGRAM OUTPUT ****          *',/,
     1 10X,
     2'      *                                                   *',/,
     3 10X,
     4'      *     COMPUTER PROGRAM FOR CALCULATING DRAWDOWN     *',/,
     5 10X,
     6'      *                                                   *',/,
     7 10X,
     8'      *     IN A CONFINED OR WATER-TABLE AQUIFER WITH     *',/,
     9 10X,
     &'      *                                                   *',/,
     1 10X,
     2'      *       AXIAL-SYMMETRIC FLOW TO A FINITE- OR        *',/,
     3 10X,
     4'      *                                                   *',/,
     5 10X,
     6'      *        INFINITESIMAL-DIAMETER PUMPED WELL         *',/,
     7 10X,
     8'      *                                                   *',/,
     9 10X,
     &'      *              VERSION 1.3, 06/29/2012              *',/,
     1 10X,
     2'      *                                                   *',/,
     3 10X,
     4'      *****************************************************',
     5/,/)
C
      RETURN
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE RDERR                    *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C14-SUBROUTINE RDERR WRITES AN ERROR MESSAGE TO THE RESULT FILE
C   AND STOPS PROGRAM EXECUTION
C
      SUBROUTINE RDERR(IO,STRING,ILINE)
C---SPECIFICATIONS
      CHARACTER STRING*80,VAR(19)*50
      DATA VAR/' TITLE',
     2         ' ANALYSIS FORMAT',
     3         ' AQUIFER TYPE',
     4         ' AQUIFER PROPERTIES',
     5         ' DRAINAGE TYPE AND NUMBER OF DRAINAGE PARAMETERS',
     6         ' DRAINAGE PARAMETERS',
     7         ' TDLAST NLC NOX',
     8         ' ITS IMEAS',
     9         ' TLAST NLC NOX',
     &         ' RERRNR RERRSUM NMAX NTMS NS',
     1         ' IPWS IPWD',
     2         ' PUMPED-WELL CHARACTERISTICS',
     3         ' NTSPW IRUN',
     4         ' PUMPED-WELL MEASURED TIME-DRAWDOWN DATA',
     5         ' NOBWC',
     6         ' IOWS IDPR IRUN',
     7         ' OBSERVATION-WELL CHARACTERISTICS',
     8         ' NTSOB',
     9         ' OBSERVATION-WELL MEASURED TIME-DRAWDOWN DATA'/
      WRITE(IO,1)ILINE
      WRITE(IO,'(A80)')STRING
      WRITE(IO,2) VAR(ILINE)
      WRITE(IO,3)

   1  FORMAT(' Aborting due to error in line from input file:',
     2 2X,I5)
   2  FORMAT(' While attempting to read variables',A40)
   3  FORMAT(' Check for incorrect positions or data types...')
      STOP
      END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE LINVST                   *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C15-SUBROUTINE LINVST CALCULATES COEFFICIENTS USED FOR THE
C   STEHFEST ALGORITHM
C
       SUBROUTINE LINVST(V,NS)
C---SPECIFICATIONS
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       DIMENSION G(20),V(20),HS(20)
C
       G(1)=1.D0
       NH=NS/2
        DO 1 IS=2,NS
1      G(IS)=G(IS-1)*IS
       HS(1)=2.D0/G(NH-1)
        DO 3 IS=2,NH
       FI=IS
       IF(IS.EQ.NH) GO TO 2
       HS(IS)=FI**(NH)*G(2*IS)/(G(NH-IS)*G(IS)*G(IS-1))
       GO TO 3
2      HS(IS)=FI**(NH)*G(2*IS)/(G(IS)*G(IS-1))
3       CONTINUE
       SN=2*(NH-NH/2*2)-1
        DO 4 IS=1,NS
       V(IS)=0.D0
       K1=(IS+1)/2
       K2=IS
       IF(K2.GT.NH)K2=NH
        DO 5 KS=K1,K2
       IF(2*KS-IS.EQ.0) GO TO 6
       IF(IS.EQ.KS)GO TO 7
       V(IS)=V(IS)+HS(KS)/(G(IS-KS)*G(2*KS-IS))
       GO TO 5
6      V(IS)=V(IS)+HS(KS)/(G(IS-KS))
       GO TO 5
7      V(IS)=V(IS)+HS(KS)/G(2*KS-IS)
5       CONTINUE
       V(IS)=SN*V(IS)
       SN=-SN
4       CONTINUE
       RETURN
       END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE LTST1                    *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C16-SUBROUTINE LTST1 CALCULATES THE LAPLACE TRANSFORM SOLUTION FOR
C   DRAWDOWN FOR FLOW TO A FULLY PENETRATING WELL OF INFINITESIMAL
C   DIAMETER IN A CONFINED AQUIFER (THEIS SOLUTION).
C
       SUBROUTINE LTST1(TD,HDT)
C---SPECIFICATIONS
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C---COMMON STATEMENTS
      COMMON /PAR2/ NGAMMA,IDRA,NS,KK,NMAX,NTMS
      COMMON /PAR9/ V(20),XLN2,EXPMAX
      COMMON /PAR10/ RD,ZD,ZD1,ZD2
C
       XP=0.D0
      DO 1 I=1,NS
       PP=XLN2*I/TD
C
       CA=RD*DSQRT(PP)
       IF(CA.GT.EXPMAX) CA=EXPMAX
       RE0=BESSK0(CA)
       PDL=RE0/PP
1     XP=XP+V(I)*PDL
       HDT=2.D0*XP*XLN2/TD
C
C---RETURN TO MAIN PROGRAM
       RETURN
       END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE LTST2                    *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C17-SUBROUTINE LTST2 CALCULATES THE LAPLACE TRANSFORM SOLUTION FOR
C   DRAWDOWN FOR FLOW TO A FINITE DIAMETER, PARTIALLY PENETRATING
C   WELL IN A CONFINED AQUIFER (MODIFIED SOLUTION OF DOUGHERTY AND
C   BABU, 1984). DELAYED DRAWDOWN RESPONSE AT OBSERVATION WELLS
C   IS INCLUDED.
C
       SUBROUTINE LTST2(TD,HD)
C---SPECIFICATIONS
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ IPWD,IRUN,IPWS,NOBWC,IOWS,IDPR
      COMMON /PAR2/ NGAMMA,IDRA,NS,KK,NMAX,NTMS
      COMMON /PAR6/ BETAW,SIGMA,GAMMA
      COMMON /PAR7/ RERRNR,RERRSUM,TDLAST,TLAST
      COMMON /PAR8/ R,ZP,Z1,Z2,WDP
      COMMON /PAR9/ V(20),XLN2,EXPMAX
      COMMON /PAR10/ RD,ZD,ZD1,ZD2
      COMMON /PAR11/ XLD,XDD,WD,SW
C
       HD=0.D0
       IF(IRUN.EQ.0.AND.KK.EQ.1) RETURN
C
       PI=3.141592653589793D0
C
       IF(IPWS.EQ.1) THEN
        XDD=0.D0
        XLD=1.D0
       ENDIF
C
       XP=0.0D0
C
      DO 1 I=1,NS
       PP=XLN2*I/TD
       Q0=DSQRT(PP)
       Q0RD=Q0*RD
       IF(Q0.GT.EXPMAX) Q0=EXPMAX
       IF(Q0RD.GT.EXPMAX) Q0RD=EXPMAX
       RE0=BESSK0(Q0)
       RE1=BESSK1(Q0)
       RE0X=BESSK0(Q0RD)
       A0=RE0*(XLD-XDD)/(Q0*RE1)
       E0=RE0X*(XLD-XDD)/(Q0*RE1)
       A=0.D0
       E=0.D0
       IF(IPWS.EQ.1) GOTO 30
       IF(IOWS.EQ.1) GOTO 30
       SUMA=0.D0
       SUME=0.D0
C
       NNN=0
C
10     NNN=NNN+1
       IF(NNN.GE.NMAX) GOTO 40
       SUMTA=SUMA
       SUMTE=SUME
       XNPI=NNN*PI
       QN=DSQRT(BETAW*XNPI*XNPI+PP)
       IF(QN.GT.EXPMAX) QN=EXPMAX
       DB=DSIN(XNPI*(1.0D0-XDD))
       DA=DSIN(XNPI*(1.0D0-XLD))
       IF(IPWS.EQ.1) DA=0.D0
       SINES=DB-DA
       RE0=BESSK0(QN)
       RE1=BESSK1(QN)
       XNUM=RE0*SINES*SINES/(XNPI*(XLD-XDD))
       XDEN=0.5D0*QN*RE1*XNPI
       A=XNUM/XDEN
       SUMA=SUMTA+A
C
       IF(KK.GT.1)THEN
        QNRD=QN*RD
        IF(QNRD.GT.EXPMAX) QNRD=EXPMAX
        RE0X=BESSK0(QNRD)
        IF(IOWS.EQ.0) 
     1   XNUM=RE0X*SINES*(DSIN(XNPI*ZD2)
     2   -DSIN(XNPI*ZD1))/(XNPI*(ZD2-ZD1))
        IF(IOWS.EQ.2) 
     1   XNUM=RE0X*SINES*DCOS(XNPI*ZD)
        E=XNUM/XDEN
        SUME=SUMTE+E
       ENDIF
C
       IF(IPWS.EQ.0.AND.NNN.LT.25) GOTO 10
       ERRA=DABS(SUMTA-SUMA)
       IF(KK.EQ.1)THEN
        IF(ERRA.LT.RERRSUM*SUMA) GOTO 40
       ENDIF
       IF(KK.GT.1)THEN
        ERRE=DABS(SUMTE-SUME)
        IF(ERRA.LT.RERRSUM*SUMA.AND.ERRE.LT.RERRSUM*SUME) GOTO 40
       ENDIF
C
       GOTO 10
C
40     CONTINUE
C
       A=SUMA
30     DENOM=(1.D0+WD*PP*(A0+A+SW))
       IF(KK.EQ.1) PDL=(A0+A+SW)/(PP*DENOM)
       IF(KK.GT.1) THEN
         E=SUME
         IF(IDPR.EQ.0) PDL=(E0+E)/(PP*DENOM)
         IF(IDPR.EQ.1) THEN
            SLUGF=1.D0/(1.D0+WDP*PP)
            PDL=SLUGF*(E0+E)/(PP*DENOM)
         ENDIF
       ENDIF
C
      XP=XP+V(I)*PDL
C
1     CONTINUE
C
       HD=2.D0*XP*XLN2/(TD*(XLD-XDD))
C
       IF(NNN.GE.NMAX) WRITE(IO,100)
C
C---FORMAT STATEMENTS
 100   FORMAT('PROGRAM CONTINUES TO NEXT TIME STEP BECAUSE NNN',
     2' EXCEEDS NMAX.')
C
C---RETURN TO MAIN PROGRAM
       RETURN
       END
C
C
C       ******************************************************
C      *                                                      *
C      *                  SUBROUTINE LTST3                    *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C18-SUBROUTINE LTST3 CALCULATES THE LAPLACE TRANSFORM SOLUTION FOR
C   DRAWDOWN FOR FLOW TO A FINITE DIAMETER, PARTIALLY PENETRATING
C   WELL IN A WATER-TABLE AQUIFER WITH DELAYED DRAWDOWN RESPONSE AT
C   OBSERVATION WELLS.
C
       SUBROUTINE LTST3(TD,HD)
C---SPECIFICATIONS
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION GAMMA(5)
C---COMMON STATEMENTS
      COMMON /IOUNIT/ IN,IO,IP
      COMMON /PAR1/ IPWD,IRUN,IPWS,NOBWC,IOWS,IDPR
      COMMON /PAR2/ NGAMMA,IDRA,NS,KK,NMAX,NTMS
      COMMON /PAR6/ BETAW,SIGMA,GAMMA
      COMMON /PAR7/ RERRNR,RERRSUM,TDLAST,TLAST
      COMMON /PAR8/ R,ZP,Z1,Z2,WDP
      COMMON /PAR9/ V(20),XLN2,EXPMAX
      COMMON /PAR10/ RD,ZD,ZD1,ZD2
      COMMON /PAR11/ XLD,XDD,WD,SW
C
       SLUGF=0.0D0
       HD=0.D0
       IF(IRUN.EQ.0.AND.KK.EQ.1) RETURN
C
C
C18a-EMPIRICAL ESTIMATE OF NECESSARY NUMBER OF NNN TERMS NEEDED FOR
C    THE FINITE SUMS. (SMALL VALUES OF BETA AND TD REQUIRE MORE
C    TERMS THAN DO LARGE VALUES.)
C
C     EMPIRICAL ESTIMATE OF NECESSARY NUMBER OF NNN TERMS NEEDED FOR THE
C     FINITE SUM. (SMALL VALUES OF BETA REQUIRE MORE TERMS THAN LARGE VALUES.)
       BETA=BETAW*RD*RD
       NX=NTMS*2.**((-DLOG10(BETA)-2.0D0))
       IF(NX.LT.4) NX=4
C
       PI=3.141592653589793D0
C
       IF(IPWS.EQ.1) THEN
        XDD=0.D0
        XLD=1.D0
       ENDIF
       IF(IOWS.EQ.1) THEN
        ZD1=0.D0
        ZD2=1.D0
       ENDIF
C
       XP=0.0D0
C
      DO 1 I=1,NS
       PP=XLN2*I/TD
       IF(IDRA.EQ.1)THEN
        RHS=0.0D0
        DO 5 J=1,NGAMMA
         RHS1=1.0D0/(SIGMA*BETAW+PP/GAMMA(J))
         RHS=RHS+RHS1
  5     CONTINUE
        XNGAMMA=NGAMMA
        RHS=PP*RHS/XNGAMMA
       ELSE
        RHS=PP/(SIGMA*BETAW)
       ENDIF
C
       SUMA=0.D0
       SUME=0.D0
       NNN=0
10     NNN=NNN+1
C
       IF(NNN.EQ.NX) GOTO 40
C
C     ASSIGN A STARTING POINT FOR EPS
       IF(NNN.GT.1) GOTO 15
       IF(RHS.LT.1.D0) EPS=DSQRT(RHS)
       IF(RHS.GE.1.D0) EPS=DATAN(RHS)
15     IF(NNN.GT.1) EPS=EPS0+PI
C
       SUMTA=SUMA
       SUMTE=SUME
C
C---CALCULATE EPSILON FOR CURRENT VALUE OF PP USING NEWTON-RAPHSON
C    TECHNIQUE
       N=0
30     EPS0=EPS
       N=N+1
       IF(N.GT.100)WRITE(IO,100)
       IF(N.GT.100)STOP
       A1=DSIN(EPS0)
       A2=DCOS(EPS0)
       F=EPS0*A1-RHS*A2
       FP=EPS0*A2+A1+RHS*A1
       EPS=EPS0-F/FP
       IF(DABS(EPS-EPS0).GT.RERRNR*EPS) GOTO 30
C
       QN=DSQRT(BETAW*EPS*EPS+PP)
       IF(QN.GT.EXPMAX) QN=EXPMAX
       DB=DSIN(EPS*(1.0D0-XDD))
       DA=DSIN(EPS*(1.0D0-XLD))
       IF(IPWS.EQ.1) DA=0.D0
       SINES=DB-DA
C
       RE0=BESSK0(QN)
       RE1=BESSK1(QN)
       XNUM=RE0*SINES*SINES/(EPS*(XLD-XDD))
       XDEN=0.5D0*QN*RE1*(EPS+0.5D0*DSIN(2.D0*EPS))
       A=XNUM/XDEN
       SUMA=SUMTA+A
C
       IF(KK.GT.1)THEN
        QNRD=QN*RD
        IF(QNRD.GT.EXPMAX) QNRD=EXPMAX
        RE0X=BESSK0(QNRD)
C
C---IF IOWS.EQ.0, THEN PARTIALLY PENETRATING OBSERVATION WELL
        IF(IOWS.EQ.0) 
     1   XNUM=RE0X*SINES*(DSIN(EPS*ZD2)
     2   -DSIN(EPS*ZD1))/(EPS*(ZD2-ZD1))
C
C---IF IOWS.EQ.1, THEN FULLY PENETRATING OBSERVATION WELL
        IF(IOWS.EQ.1) 
     1   XNUM=RE0X*SINES*DSIN(EPS)/EPS
C
C---IF IOWS.EQ.2, THEN OBSERVATION PIEZOMETER
        IF(IOWS.EQ.2) 
     1   XNUM=RE0X*SINES*DCOS(EPS*ZD)
        E=XNUM/XDEN
        SUME=SUMTE+E
       ENDIF
C
       GOTO 10
C
 40    CONTINUE
C
       A=SUMA
       DENOM=(1.D0+WD*PP*(A+SW))
       IF(KK.EQ.1) PDL=(A+SW)/(PP*DENOM)
       IF(KK.GT.1) THEN
         E=SUME
         IF(IDPR.EQ.0) PDL=E/(PP*DENOM)
         IF(IDPR.EQ.1) THEN
            SLUGF=1.D0/(1.D0+WDP*PP)
            PDL=SLUGF*E/(PP*DENOM)
         ENDIF
       ENDIF
C
      XP=XP+V(I)*PDL
C
1     CONTINUE
C
      HD=2.D0*XP*XLN2/(TD*(XLD-XDD))
C
C---FORMAT STATEMENTS
  100 FORMAT(' PROGRAM STOPPED BECAUSE NEWTON-RAPHSON ITERATIONS',
     2' EXCEED 100')
C
C---RETURN TO MAIN PROGRAM
      RETURN
      END
C
C       ******************************************************
C      *                                                      *
C      *                    FUNCTION BESSK0                   *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C19-FUNCTION BESSK0 CALCULATES THE ZERO-ORDER MODIFIED BESSEL FUNCTION
C    OF THE SECOND KIND. SOURCE: PRESS AND OTHERS (1992).
      DOUBLE PRECISION FUNCTION BESSK0(X)
C---SPECIFICATIONS
      DOUBLE PRECISION X,Y,P1,P2,P3,P4,P5,P6,P7,
     *    Q1,Q2,Q3,Q4,Q5,Q6,Q7,BESSI0
      DATA P1,P2,P3,P4,P5,P6,P7/-0.57721566D0,0.42278420D0,0.23069756D0,
     *    0.3488590D-1,0.262698D-2,0.10750D-3,0.74D-5/
      DATA Q1,Q2,Q3,Q4,Q5,Q6,Q7/1.25331414D0,-0.7832358D-1,0.2189568D-1,
     *    -0.1062446D-1,0.587872D-2,-0.251540D-2,0.53208D-3/
C
      IF (X.LE.2.D0) THEN
        Y=X*X/4.D0
        BESSK0=(-DLOG(X/2.D0)*BESSI0(X))+(P1+Y*(P2+Y*(P3+
     *        Y*(P4+Y*(P5+Y*(P6+Y*P7))))))
      ELSE
        Y=(2.D0/X)
        BESSK0=(DEXP(-X)/DSQRT(X))*(Q1+Y*(Q2+Y*(Q3+
     *        Y*(Q4+Y*(Q5+Y*(Q6+Y*Q7))))))
      ENDIF
C
C---RETURN TO MAIN PROGRAM
      RETURN
      END
C
C       ******************************************************
C      *                                                      *
C      *                    FUNCTION BESSI0                   *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C20-FUNCTION BESSI0 CALCULATES THE ZERO-ORDER MODIFIED BESSEL FUNCTION 
C    OF THE FIRST KIND. SOURCE: PRESS AND OTHERS (1992).
      DOUBLE PRECISION FUNCTION BESSI0(X)
C---SPECIFICATIONS
      DOUBLE PRECISION X,Y,AX,P1,P2,P3,P4,P5,P6,P7,
     *    Q1,Q2,Q3,Q4,Q5,Q6,Q7,Q8,Q9
      DATA P1,P2,P3,P4,P5,P6,P7/1.0D0,3.5156229D0,3.0899424D0,1.2067492D
     *0,
     *    0.2659732D0,0.360768D-1,0.45813D-2/
      DATA Q1,Q2,Q3,Q4,Q5,Q6,Q7,Q8,Q9/0.39894228D0,0.1328592D-1,
     *    0.225319D-2,-0.157565D-2,0.916281D-2,-0.2057706D-1,
     *    0.2635537D-1,-0.1647633D-1,0.392377D-2/
C
      IF (DABS(X).LT.3.75D0) THEN
        Y=(X/3.75D0)**2
        BESSI0=P1+Y*(P2+Y*(P3+Y*(P4+Y*(P5+Y*(P6+Y*P7)))))
      ELSE
        AX=DABS(X)
        Y=3.75D0/AX
        BESSI0=(DEXP(AX)/DSQRT(AX))*(Q1+Y*(Q2+Y*(Q3+Y*(Q4
     *      +Y*(Q5+Y*(Q6+Y*(Q7+Y*(Q8+Y*Q9))))))))
      ENDIF
C
C---RETURN TO MAIN PROGRAM
      RETURN
      END
C
C       ******************************************************
C      *                                                      *
C      *                    FUNCTION BESSK1                   *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C21-FUNCTION BESSK1 CALCULATES THE FIRST-ORDER MODIFIED BESSEL FUNCTION 
C    OF THE SECOND KIND. SOURCE: PRESS AND OTHERS (1992).
      DOUBLE PRECISION FUNCTION BESSK1(X)
C---SPECIFICATIONS
      DOUBLE PRECISION X,Y,P1,P2,P3,P4,P5,P6,P7,
     *    Q1,Q2,Q3,Q4,Q5,Q6,Q7,BESSI1
      DATA P1,P2,P3,P4,P5,P6,P7/1.0D0,0.15443144D0,-0.67278579D0,
     *    -0.18156897D0,-0.1919402D-1,-0.110404D-2,-0.4686D-4/
      DATA Q1,Q2,Q3,Q4,Q5,Q6,Q7/1.25331414D0,0.23498619D0,-0.3655620D-1,
     *    0.1504268D-1,-0.780353D-2,0.325614D-2,-0.68245D-3/
C
      IF (X.LE.2.0) THEN
        Y=X*X/4.0
        BESSK1=(LOG(X/2.0)*BESSI1(X))+(1.0/X)*(P1+Y*(P2+
     *      Y*(P3+Y*(P4+Y*(P5+Y*(P6+Y*P7))))))
      ELSE
        Y=2.0/X
        BESSK1=(EXP(-X)/SQRT(X))*(Q1+Y*(Q2+Y*(Q3+
     *      Y*(Q4+Y*(Q5+Y*(Q6+Y*Q7))))))
      ENDIF
C
C---RETURN TO MAIN PROGRAM
      RETURN
      END
C
C       ******************************************************
C      *                                                      *
C      *                    FUNCTION BESSI1                   *
C      *                                                      *
C      *          VERSION 1.0 CURRENT AS OF 10/01/99          *
C      *                                                      *
C       ******************************************************
C
C22-FUNCTION BESSI1 CALCULATES THE FIRST-ORDER MODIFIED BESSEL FUNCTION 
C    OF THE FIRST KIND. SOURCE: PRESS AND OTHERS (1992).
      DOUBLE PRECISION FUNCTION BESSI1(X)
C---SPECIFICATIONS
      DOUBLE PRECISION X,Y,AX,P1,P2,P3,P4,P5,P6,P7,
     *    Q1,Q2,Q3,Q4,Q5,Q6,Q7,Q8,Q9
      DATA P1,P2,P3,P4,P5,P6,P7/0.5D0,0.87890594D0,0.51498869D0,
     *    0.15084934D0,0.2658733D-1,0.301532D-2,0.32411D-3/
      DATA Q1,Q2,Q3,Q4,Q5,Q6,Q7,Q8,Q9/0.39894228D0,-0.3988024D-1,
     *    -0.362018D-2,0.163801D-2,-0.1031555D-1,0.2282967D-1,
     *    -0.2895312D-1,0.1787654D-1,-0.420059D-2/
C
      IF (ABS(X).LT.3.75) THEN
        Y=(X/3.75)**2
        BESSI1=X*(P1+Y*(P2+Y*(P3+Y*(P4+Y*(P5+Y*(P6+Y*P7))))))
      ELSE
        AX=ABS(X)
        Y=3.75/AX
        BESSI1=(EXP(AX)/SQRT(AX))*(Q1+Y*(Q2+Y*(Q3+Y*(Q4+
     *      Y*(Q5+Y*(Q6+Y*(Q7+Y*(Q8+Y*Q9))))))))
      ENDIF
C
C---RETURN TO MAIN PROGRAM
      RETURN
      END
